workspace

package
v0.1.24 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2026 License: GPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DidChangeConfiguration

func DidChangeConfiguration(req *types.RequestContext, params *protocol.DidChangeConfigurationParams) error

DidChangeConfiguration handles the workspace/didChangeConfiguration notification

func DidChangeWatchedFiles

func DidChangeWatchedFiles(req *types.RequestContext, params *protocol.DidChangeWatchedFilesParams) error

DidChangeWatchedFiles handles the workspace/didChangeWatchedFiles notification

func LogError

func LogError(context *glsp.Context, format string, args ...any)

LogError logs an error message to stderr and optionally to the LSP client

func LogWarning

func LogWarning(context *glsp.Context, format string, args ...any)

LogWarning logs a warning message to stderr and optionally to the LSP client

func ShowMessage

func ShowMessage(context *glsp.Context, messageType protocol.MessageType, message string)

ShowMessage sends a message to be displayed to the user

Types

This section is empty.

Jump to