Documentation
¶
Index ¶
- func DidChangeConfiguration(req *types.RequestContext, params *protocol.DidChangeConfigurationParams) error
- func DidChangeWatchedFiles(req *types.RequestContext, params *protocol.DidChangeWatchedFilesParams) error
- func LogError(context *glsp.Context, format string, args ...any)
- func LogWarning(context *glsp.Context, format string, args ...any)
- func ShowMessage(context *glsp.Context, messageType protocol.MessageType, message string)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DidChangeConfiguration ¶
func DidChangeConfiguration(req *types.RequestContext, params *protocol.DidChangeConfigurationParams) error
DidChangeConfiguration handles the workspace/didChangeConfiguration notification
func DidChangeWatchedFiles ¶
func DidChangeWatchedFiles(req *types.RequestContext, params *protocol.DidChangeWatchedFilesParams) error
DidChangeWatchedFiles handles the workspace/didChangeWatchedFiles notification
func LogWarning ¶
LogWarning logs a warning message to stderr and optionally to the LSP client
func ShowMessage ¶
func ShowMessage(context *glsp.Context, messageType protocol.MessageType, message string)
ShowMessage sends a message to be displayed to the user
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.